@@ -28,5 +28,5 @@ pub fn generate(save_name: &'static str, save_size: i32) {
 }
 
 pub fn exists(save_name: &'static str) -> bool {
-    return Path::new(save_name).exists() == false;
+    return Path::new(save_name).exists();
 }
